////////////////////////////////////////////////////////////////////////////////////////////
// Class MiniIMU9Compass - Defines an interface to the LSM303DLM accelerometer and compass
//                         on the Pololu MiniIMU9 board.  The IMU does not break out all
//                         functionality from the chip so not all registers from the device
//                         are implemented with functions.
//
//
// Copyright Kyle Crane 2012.  See Bottom for License Terms
////////////////////////////////////////////////////////////////////////////////////////////

#ifndef MINI_IMU_9_COMPASS_H_
#define MINI_IMU_9_COMPASS_H_

#include <stdint.h>
#include <propeller.h>
#include "I2CBus.h"

enum COMPASS_CONSTATNTS
{
	MIMU_MAG_ADR	= 0x1E,
	
	// Compass Register bit masks
    M_DATA_RATE_M   = 0x1C,
    M_GAIN_M		= 0xE0,
    M_OP_MODE_M		= 0x03,
    
    // Comapass Register addresses
    M_CRA_REG 		= 0x00,
	M_CRB_REG 		= 0x01,
	M_MR_REG 		= 0x02,
	M_OUT_X_H 		= 0x03,
	M_OUT_X_L 		= 0x04,
	M_OUT_Z_H 		= 0x05,
	M_OUT_Z_L 		= 0x06,
	M_OUT_Y_H 		= 0x07,
	M_OUT_Y_L 		= 0x08,
	M_SR_REG 		= 0x09,
	M_IRA_REG 		= 0x0A,
	M_IRB_REG 		= 0x0B,
	M_IRC_REG 		= 0x0C
};

class MiniIMU9Compass
{
    private:
        uint16_t m_data[3];
        uint8_t  m_addr;
        I2C*     m_bus;
    
    public:
        MiniIMU9Compass();
        ~MiniIMU9Compass();
        void Init(I2C& bus);
        void Init(I2C& bus, uint8_t addr);

        int IsOnline();                                 // Returns: 1=Online 0=Offline.
        int WriteReg(uint8_t reg, uint8_t value);       // Write the value to specified Register.		(-1 Error)
        uint8_t ReadReg(uint8_t reg);                   // Returns the value stores at the specified register. (-1 Error)
        int16_t ReadChannel(uint8_t chan);              // Returns the current value from the accel channel.   (-1 Error)
        int ReadAllChannels(int16_t* buffer);		    // Read all 3 channels from the register data in a single bus transaction. (-1 Error)
        int16_t GetChannel(uint8_t chan);               // Returns the values provided from MiniIMU9Core if active.
        
        int Enable(uint8_t value);                      // Enable device and set operating mode 0 - 3. (-1 Error)
        int SetGain(uint8_t value); 					// Set the magnetic gain for the sensor 0 - 3. (-1 Error)
        int SetDataRate(uint8_t value);					// Set the minimum register update rate 0 - 3. (-1 Error)
}; 


#endif



/*
Permission is hereby granted, free of charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.
*/
