/*
 * MiniIMU9Gyro.h
 *
 *  Created on: Aug 9, 2012
 *      Author: kcrane
 */

#ifndef MINIIMU9GYRO_H_
#define MINIIMU9GYRO_H_

#include <propeller.h>
#include "I2CBus.h"

enum GYRO_CONSTANTS
{
    MIMU_GYRO_ADR  = 0x69,

    G_AUTO_INC_M    = 0x80,
    G_DATA_RATE_M 	= 0xC0,
    G_BNDWDTH_M		= 0x30,
    G_POWERMD_M		= 0x08,
    G_AXIS_EN_M		= 0x07,
    G_HP_FILTER_M   = 0x30,
    G_HP_CUTOFF_M   = 0x0F,
    G_UPDATE_MODE_M = 0x80,
    G_DATA_ORDER_M  = 0x40,
    G_FULL_SCALE_M  = 0x30,
    G_CLEAR_MEM_M   = 0x80,
    G_FIFO_EN_M		= 0x40,
    G_HP_FLTR_EN_M  = 0x20,

    G_CTRL_REG1	   = 0x20,
    G_CTRL_REG2,
    G_CTRL_REG3,
    G_CTRL_REG4,
    G_CTRL_REG5,
    G_REF_REG,
    G_TEMP_REG,
    G_STATUS_REG,
    G_OUT_X_L,
    G_OUT_X_H,
    G_OUT_Y_L,
    G_OUT_Y_H,
    G_OUT_Z_L,
    G_OUT_Z_H,
    G_FIFO_CTRL_REG,
    G_FIFO_SRC_REG,
    G_INT1_CFG_REG,
    G_INT1_SRC_REG,
    G_INT1_TSH_XH_REG,
    G_INT1_TSH_XL_REG,
    G_INT1_TSH_YH_REG,
    G_INT1_TSH_YL_REG,
    G_INT1_TSH_ZH_REG,
    G_INT1_TSH_ZL_REG
};


class MiniIMU9Gyro
{
private:
	uint16_t m_data[3];
	uint8_t  m_addr;
    I2C*     m_bus;

public:
	MiniIMU9Gyro();
	~MiniIMU9Gyro();
	void Init(I2C& bus);
	void Init(I2C& bus, uint8_t addr);

	int IsOnline();
	int WriteReg(int reg, int value);
	int ReadReg(int reg);
	int16_t ReadChannel(uint8_t chan);
	int	ReadAllChannels(int16_t* buffer);			// Read all 3 channels from the register data in a single bus transaction. (-1 Error)
	int16_t GetChannel(uint8_t chan);               // Returns the values provided from MiniIMU9Core if active.


	int Enable(uint8_t val);          	            // Enable device and set operating mode 0 - 3.  (-1 Error)
	int SetByteOrder(uint8_t val);         	        // Set register order 0(LSB First) - 1(MSB First)   (-1 Error)
	int SetUpdateMode(uint8_t val);                	// Set output update mode 0(Continuous) - 1(Atomic)  (-1 Error)
};


#endif /* MINIIMU9GYRO_H_ */
